#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-middleware-static
version:              0.9.0
visibility:           public
id:                   wai-middleware-static-0.9.0-A4Hg1CUqeubEtK3iWLssRo
key:                  wai-middleware-static-0.9.0-A4Hg1CUqeubEtK3iWLssRo
license:              BSD-3-Clause
copyright:            (c) 2012-2014 Andrew Farmer
maintainer:           Andrew Farmer <afarmer@ittc.ku.edu>
author:               Andrew Farmer <afarmer@ittc.ku.edu>
stability:            experimental
homepage:             https://github.com/scotty-web/wai-middleware-static
synopsis:             WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.

    [WAI] <http://hackage.haskell.org/package/wai>

category:             Web
abi:                  09c1b1b992f07f051a9ca01d895ada69
exposed:              True
exposed-modules:      Network.Wai.Middleware.Static
import-dirs:          /usr/lib/ghc-8.10.5/site-local/wai-middleware-static-0.9.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/wai-middleware-static-0.9.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/i386-linux-ghc-8.10.5/wai-middleware-static-0.9.0

hs-libraries:         HSwai-middleware-static-0.9.0-A4Hg1CUqeubEtK3iWLssRo
depends:
    base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1
    cryptonite-0.29-KSQcZnQaH5M3lIm9Vzc7YS directory-1.3.6.0
    expiring-cache-map-0.0.6.1-LAghdEmAJsc82Wqe3DamUz filepath-1.4.2.1
    http-types-0.12.3-JSCBEGU6f6MIPS3hXwEPIB
    memory-0.16.0-E1gXzMJzgEcJ8QhI9dLs6S
    mime-types-0.1.0.9-2ORfbvGCmlz3ckhb8dUDtI
    old-locale-1.0.0.7-L6Wsx5CTYHFJNpULKIS1yv text-1.2.4.1 time-1.9.3
    wai-3.2.3-6NrdunSiuKK6vnccK2cwty

haddock-interfaces:
    /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

